local AddonName, a = ...
if a.BuildFail(50000) then return end
local L = a.Localize
local s = SpellFlashAddon
local x = s.UpdatedVariables
local talent = x.Talent
local equipped = x.Equipped
local dot = x.Dot
local buff = x.Buff
local debuff = x.Debuff
local cooldown = x.Cooldown
local set_bonus = x.SetBonus
local artifact = x.Artifact

-- SpellFlash API:
-- http://wow.curseforge.com/addons/spellflash/pages/api/

-- Updated variable references:
-- http://wow.curseforge.com/addons/spellflash/pages/api/#w-local-x-spell-flash-addon-updated-variables
-- x.EnemyDetected, x.EnemyDetected, x.NoCC, x.InInstance, x.InstanceType, x.PetAlive, x.PetActiveEnemy, x.PetNoCC, x.Lag, x.DoubleLag, x.ThreatPercent, x.EnemyDetected, x.ShouldPermanentBuff, x.ShouldTemporaryBuff

-- Spell table references:
-- http://wow.curseforge.com/addons/spellflash/pages/api/#w-s-castable

,"heroic_leap,if=movement.distance>5"
,"heroic_leap,if=(raid_event.movement.distance>25&raid_event.movement.in>45)|!raid_event.movement.exists"

a.spells["potion,if=buff.battle_cry.up&(buff.avatar.up|!talent.avatar.enabled)"] = {
	Type = "item",
	ID = 229206--[[Potion of Prolonged Power]],
	EnemyTargetNeeded = true,
	NoGCD = true,
	Check = function(z)
		return x.ShouldTemporaryBuff and s.Boss("target") and (buff.battle_cry.up and (buff.avatar.up or not talent.avatar.enabled))
	end,
	FlashColor = "Yellow",
	Continue = true,
	FlashID = {229206--[[Potion of Prolonged Power]], 127844--[[Potion of the Old War]]},
}

a.spells["dragon_roar,if=(equipped.convergence_of_fates&cooldown.battle_cry.remains<2)|!equipped.convergence_of_fates&(!cooldown.battle_cry.remains<=10|cooldown.battle_cry.remains<2)|(talent.bloodbath.enabled&(cooldown.bloodbath.remains<1|buff.bloodbath.up))"] = {
	ID = 118000--[[Dragon Roar]],
	Check = function(z)
		return (equipped.convergence_of_fates and cooldown.battle_cry.remains < 2) or not equipped.convergence_of_fates and (cooldown.battle_cry.remains > 10 or cooldown.battle_cry.remains < 2) or (talent.bloodbath.enabled and (cooldown.bloodbath.remains < 1 or buff.bloodbath.up))
	end,
	NoGCD = true,
	FlashColor = "Yellow",
}

a.spells["rampage,if=cooldown.battle_cry.remains<1&cooldown.bloodbath.remains<1&target.health.pct>20"] = {
	ID = 184367--[[Rampage]],
	CheckFirst = function(z)
		return x.CanRampage and (cooldown.battle_cry.remains < 1 + x.GCD and cooldown.bloodbath.remains < 1 + x.GCD and s.HealthPercent("target") > 20)
	end,
}

a.spells["furious_slash,if=talent.frenzy.enabled&(buff.frenzy.stack<3|buff.frenzy.remains<3|(cooldown.battle_cry.remains<1&buff.frenzy.remains<9))"] = {
	ID = 100130--[[Furious Slash]],
	CheckFirst = function(z)
		return talent.frenzy.enabled and (buff.frenzy.stack < 3 or buff.frenzy.remains < 3 + x.GCD or (cooldown.battle_cry.remains < 1 + x.GCD and buff.frenzy.remains < 9 + x.GCD))
	end,
}

a.spells["use_item,name=umbral_moonglaives,if=equipped.umbral_moonglaives&(cooldown.battle_cry.remains>gcd&cooldown.battle_cry.remains<2|cooldown.battle_cry.remains=0)"] = {
	Type = "item",
	ID = 147012--[[Umbral Moonglaives]],
	EnemyTargetNeeded = true,
	NoGCD = true,
	Check = function(z)
		return x.InCombat and x.ShouldTemporaryBuff and equipped.umbral_moonglaives and (cooldown.battle_cry.remains > x.MaxGCD and cooldown.battle_cry.remains < 2 or cooldown.battle_cry.remains == 0)
	end,
	FlashColor = "Yellow",
	Continue = true,
}

a.spells["bloodthirst,if=equipped.kazzalax_fujiedas_fury&buff.fujiedas_fury.down"] = {
	ID = 23881--[[Bloodthirst]],
	CheckFirst = function(z)
		return equipped.kazzalax_fujiedas_fury and buff.fujiedas_fury.down
	end,
}

a.spells["avatar,if=((buff.battle_cry.remains>5|cooldown.battle_cry.remains<12)&target.time_to_die>80)|((target.time_to_die<40)&(buff.battle_cry.remains>6|cooldown.battle_cry.remains<12|(target.time_to_die<20)))"] = {
	ID = 107574--[[Avatar]],
	Check = function(z)
		return x.InCombat and x.ShouldTemporaryBuff and (((buff.battle_cry.remains > 5 or cooldown.battle_cry.remains < 12) and x.TimeToDie > 80) or ((x.TimeToDie < 40) and (buff.battle_cry.remains > 6 or cooldown.battle_cry.remains < 12 or (x.TimeToDie < 20))))
	end,
	NoGCD = true,
	FlashColor = "Yellow",
}

a.spells["battle_cry,if=gcd.remains=0&talent.reckless_abandon.enabled&!talent.bloodbath.enabled&(equipped.umbral_moonglaives&(prev_off_gcd.umbral_moonglaives|(trinket.cooldown.remains>3&trinket.cooldown.remains<90))|!equipped.umbral_moonglaives)"] = {
	ID = 1719--[[Battle Cry]],
	NoRangeCheck = true,
	CheckFirst = function(z)
		return x.InCombat and x.ShouldTemporaryBuff and talent.reckless_abandon.enabled and not talent.bloodbath.enabled and (equipped.umbral_moonglaives and cooldown.umbral_glaive_storm.remains > 3 and cooldown.umbral_glaive_storm.remains < 90 or not equipped.umbral_moonglaives)
	end,
	NoGCD = true,
	FlashColor = "Yellow",
}

a.spells["battle_cry,if=gcd.remains=0&talent.bladestorm.enabled&(raid_event.adds.in>90|!raid_event.adds.exists|spell_targets.bladestorm_mh>desired_targets)"] = {
	ID = 1719--[[Battle Cry]],
	NoRangeCheck = true,
	CheckFirst = function(z)
		return x.InCombat and x.ShouldTemporaryBuff and talent.bladestorm.enabled and (s.Boss("target") or x.ActiveEnemies >= 3)
	end,
	NoGCD = true,
	FlashColor = "Yellow",
}

a.spells["battle_cry,if=gcd.remains=0&buff.dragon_roar.up&(cooldown.bloodthirst.remains=0|buff.enrage.remains>cooldown.bloodthirst.remains)"] = {
	ID = 1719--[[Battle Cry]],
	NoRangeCheck = true,
	CheckFirst = function(z)
		return x.InCombat and x.ShouldTemporaryBuff and buff.dragon_roar.up and (cooldown.bloodthirst.remains==0 or buff.enrage.remains > cooldown.bloodthirst.remains)
	end,
	NoGCD = true,
	FlashColor = "Yellow",
}


a.spells["battle_cry,if=(gcd.remains=0|gcd.remains<=0.4&prev_gcd.1.rampage)&(cooldown.bloodbath.remains=0|buff.bloodbath.up|!talent.bloodbath.enabled|(target.time_to_die<12))&(equipped.umbral_moonglaives&(prev_off_gcd.umbral_moonglaives|(trinket.cooldown.remains>3&trinket.cooldown.remains<90))|!equipped.umbral_moonglaives)"] = {
	ID = 1719--[[Battle Cry]],
	NoRangeCheck = true,
	CheckFirst = function(z)
		return x.InCombat and x.ShouldTemporaryBuff and ((cooldown.bloodbath.remains == 0 or buff.bloodbath.up or not talent.bloodbath.enabled or (x.TimeToDie < 12)) and (equipped.umbral_moonglaives and (cooldown.umbral_glaive_storm.remains > 3 and cooldown.umbral_glaive_storm.remains < 90) or not equipped.umbral_moonglaives))
	end,
	NoGCD = true,
	FlashColor = "Yellow",
}

a.spells["bloodbath,if=buff.battle_cry.up|(target.time_to_die<14)|(cooldown.battle_cry.remains<2&prev_gcd.1.rampage)"] = {
	ID = 12292--[[Bloodbath]],
	CheckFirst = function(z)
		return x.InCombat and x.ShouldTemporaryBuff and (buff.battle_cry.up or x.TimeToDie < 14 or (cooldown.battle_cry.remains < 2 and GetTime() - x.LastRampage < 2))
	end,
	NoGCD = true,
	FlashColor = "Yellow",
}

a.spells["blood_fury,if=buff.battle_cry.up"] = {
	ID = 20572--[[Blood Fury]],
	CheckFirst = function(z)
		return x.InCombat and x.ShouldTemporaryBuff and buff.battle_cry.up
	end,
	NoGCD = true,
	FlashColor = "Yellow",
}

a.spells["berserking,if=(buff.battle_cry.up&(buff.avatar.up|!talent.avatar.enabled))|(buff.battle_cry.up&target.time_to_die<40)"] = {
	ID = 26297--[[Berserking]],
	CheckFirst = function(z)
		return x.InCombat and x.ShouldTemporaryBuff and ((buff.battle_cry.up and (buff.avatar.up or not talent.avatar.enabled)) or (buff.battle_cry.up and x.TimeToDie < 40))
	end,
	NoGCD = true,
	FlashColor = "Yellow",
}

a.spells["arcane_torrent,if=rage<rage.max-40"] = {
	ID = 69179--[[Arcane Torrent]],
	CheckFirst = function(z)
		return x.InCombat and x.ShouldTemporaryBuff and x.RageDeficit > 40
	end,
	NoGCD = true,
	FlashColor = "Yellow",
}

,"lights_judgment,if=buff.battle_cry.up"

--[[
   _____            _     _                         
  / ____|          | |   | |                        
 | |     ___   ___ | | __| | _____      ___ __  ___ 
 | |    / _ \ / _ \| |/ _` |/ _ \ \ /\ / / '_ \/ __|
 | |___| (_) | (_) | | (_| | (_) \ V  V /| | | \__ \
  \_____\___/ \___/|_|\__,_|\___/ \_/\_/ |_| |_|___/
                                                    
]]

a.spells["bloodthirst,if=target.health.pct<20&buff.enrage.remains<1"] = {
	ID = 23881--[[Bloodthirst]],
	CheckFirst = function(z)
		return s.HealthPercent("target") < 20 and buff.enrage.remains < 1 + x.GCD
	end,
}

a.spells["raging_blow,if=talent.inner_rage.enabled&buff.enrage.up"] = {
	ID = 85288--[[Raging Blow]],
	CheckFirst = function(z)
		return talent.inner_rage.enabled and buff.enrage.up
	end,
}

a.spells["rampage,if=(rage>=100&talent.frothing_berserker.enabled&!set_bonus.tier21_4pc)|set_bonus.tier21_4pc|!talent.frothing_berserker.enabled"] = {
	ID = 184367--[[Rampage]],
	CheckFirst = function(z)
		return x.CanRampage and ((x.Rage >= 100 and talent.frothing_berserker.enabled and not set_bonus.tier21_4pc) or set_bonus.tier21_4pc or not talent.frothing_berserker.enabled)
	end,
}

a.spells["odyns_fury,if=buff.enrage.up&(cooldown.raging_blow.remains>0|!talent.inner_rage.enabled)"] = {
	ID = 205545--[[Odyn's Fury]],
	NoRangeCheck = true,
	CheckFirst = function(z)
		return buff.enrage.up and (cooldown.raging_blow.remains > x.GCD or not talent.inner_rage.enabled)
	end,
}

a.spells["berserker_rage,if=talent.outburst.enabled&buff.enrage.down&buff.battle_cry.up"] = {
	ID = 18499--[[Berserker Rage]],
	CheckFirst = function(z)
		return talent.outburst.enabled and buff.enrage.down and buff.battle_cry.up
	end,
	FlashColor = "Yellow",
	NoGCD = true,
}

a.spells["bloodthirst,if=(buff.enrage.remains<1&!talent.outburst.enabled)|!talent.inner_rage.enabled"] = {
	ID = 23881--[[Bloodthirst]],
	CheckFirst = function(z)
		return (buff.enrage.remains < 1 + x.GCD and not talent.outburst.enabled) or not talent.inner_rage.enabled
	end,
}


--[[
                ______ 
     /\        |  ____|
    /  \   ___ | |__   
   / /\ \ / _ \|  __|  
  / ____ \ (_) | |____ 
 /_/    \_\___/|______|
                       
]]
a.spells["bloodthirst,if=buff.enrage.down|rage<90"] = {
	ID = 23881--[[Bloodthirst]],
	CheckFirst = function(z)
		return buff.enrage.down or x.Rage < 90
	end,
}

a.spells["bladestorm,if=buff.enrage.remains>2&(raid_event.adds.in>90|!raid_event.adds.exists|spell_targets.bladestorm_mh>desired_targets)"] = {
	ID = 46924--[[Bladestorm]],
	CheckFirst = function(z)
		return talent.bladestorm.enabled and buff.enrage.remains > 2 + x.GCD and (s.Boss("target") or x.ActiveEnemies > 3)
	end,
}

a.spells["whirlwind,if=buff.meat_cleaver.down"] = {
	ID = 1680--[[Whirlwind]],
	NoRangeCheck = true,
	Melee = true,
	CheckFirst = function(z)
		return buff.meat_cleaver.down
	end,
}

a.spells["rampage,if=buff.meat_cleaver.up&(buff.enrage.down&!talent.frothing_berserker.enabled|buff.massacre.react|rage>=100)"] = {
	ID = 184367--[[Rampage]],
	CheckFirst = function(z)
		return x.CanRampage and (buff.meat_cleaver.up and (buff.enrage.down and not talent.frothing_berserker.enabled or buff.massacre.up or x.Rage >= 100))
	end,
}

--[[
  ______                     _       
 |  ____|                   | |      
 | |__  __  _____  ___ _   _| |_ ___ 
 |  __| \ \/ / _ \/ __| | | | __/ _ \
 | |____ >  <  __/ (__| |_| | ||  __/
 |______/_/\_\___|\___|\__,_|\__\___|
                                     
]]

a.spells["execute,if=artifact.juggernaut.enabled&(!buff.juggernaut.up|buff.juggernaut.remains<2)|buff.stone_heart.react"] = {
	ID = 5308--[[Execute]],
	CheckFirst = function(z)
		if not artifact.juggernaut then
			artifact.juggernaut = {}
			artifact.juggernaut.enabled = false
		end
		return artifact.juggernaut.enabled and (not buff.juggernaut.up or buff.juggernaut.remains < 2 + x.GCD) or buff.stone_heart.up
	end,
	FlashColor = "Orange",
}

a.spells["furious_slash,if=talent.frenzy.enabled&buff.frenzy.remains<=2"] = {
	ID = 100130--[[Furious Slash]],
	CheckFirst = function(z)
		return talent.frenzy.enabled and buff.frenzy.remains <= 2 + x.GCD
	end,
}

a.spells["rampage,if=buff.massacre.react&buff.enrage.remains<1"] = {
	ID = 184367--[[Rampage]],
	CheckFirst = function(z)
		return buff.massacre.up and buff.enrage.remains < 1 + x.GCD
	end,
}

a.spells["odyns_fury"] = {
	ID = 205545--[[Odyn's Fury]],
	NoRangeCheck = true,
	CheckFirst = function(z)
		return x.InCombat
	end,
}

a.spells["furious_slash,if=set_bonus.tier19_2pc"] = {
	ID = 100130--[[Furious Slash]],
	CheckFirst = function(z)
		return set_bonus.tier19_2pc
	end,
}

--[[
   _____ _             _        _______                   _   
  / ____(_)           | |      |__   __|                 | |  
 | (___  _ _ __   __ _| | ___     | | __ _ _ __ __ _  ___| |_ 
  \___ \| | '_ \ / _` | |/ _ \    | |/ _` | '__/ _` |/ _ \ __|
  ____) | | | | | (_| | |  __/    | | (_| | | | (_| |  __/ |_ 
 |_____/|_|_| |_|\__, |_|\___|    |_|\__,_|_|  \__, |\___|\__|
                  __/ |                         __/ |         
                 |___/                         |___/          ]]


a.spells["bloodthirst,if=buff.fujiedas_fury.up&buff.fujiedas_fury.remains<2"] = {
	ID = 23881--[[Bloodthirst]],
	CheckFirst = function(z)
		return buff.fujiedas_fury.up and buff.fujiedas_fury.remains < 2 + x.GCD
	end,
}

a.spells["furious_slash,if=talent.frenzy.enabled&(buff.frenzy.down|buff.frenzy.remains<=2)"] = {
	ID = 100130--[[Furious Slash]],
	CheckFirst = function(z)
		return talent.frenzy.enabled and (buff.frenzy.down or buff.frenzy.remains <= 2 + x.GCD)
	end,
}

a.spells["raging_blow,if=buff.enrage.up&talent.inner_rage.enabled"] = {
	ID = 85288--[[Raging Blow]],
	CheckFirst = function(z)
		return buff.enrage.up and talent.inner_rage.enabled
	end,
}

a.spells["rampage,if=target.health.pct>21&(rage>=100|!talent.frothing_berserker.enabled)&(((cooldown.battle_cry.remains>5|cooldown.bloodbath.remains>5)&!talent.carnage.enabled)|((cooldown.battle_cry.remains>3|cooldown.bloodbath.remains>3)&talent.carnage.enabled))|buff.massacre.react"] = {
	ID = 184367--[[Rampage]],
	CheckFirst = function(z)
		return x.CanRampage and (s.HealthPercent("target") > 21 and (x.Rage>=100 or not talent.frothing_berserker.enabled) and (((cooldown.battle_cry.remains > 5 + x.GCD or cooldown.bloodbath.remains > 5 + x.GCD) and not talent.carnage.enabled) or ((cooldown.battle_cry.remains > 3 + x.GCD or cooldown.bloodbath.remains > 3 + x.GCD) and talent.carnage.enabled)) or buff.massacre.up)
	end,
}

a.spells["execute,if=buff.stone_heart.react&((talent.inner_rage.enabled&cooldown.raging_blow.remains>1)|buff.enrage.up)"] = {
	ID = 5308--[[Execute]],
	CheckFirst = function(z)
		return x.Rage >= 25 and (buff.stone_heart.up and ((talent.inner_rage.enabled and cooldown.raging_blow.remains > 1 + x.GCD) or buff.enrage.up))
	end,
	FlashColor = "Orange",
}

a.spells["bloodthirst"] = {
	ID = 23881--[[Bloodthirst]],
}

a.spells["furious_slash,if=set_bonus.tier19_2pc&!talent.inner_rage.enabled"] = {
	ID = 100130--[[Furious Slash]],
	CheckFirst = function(z)
		return set_bonus.tier19_2pc and not talent.inner_rage.enabled
	end,
}

a.spells["whirlwind,if=buff.wrecking_ball.react&buff.enrage.up"] = {
	ID = 1680--[[Whirlwind]],
	NoRangeCheck = true,
	Melee = true,
	CheckFirst = function(z)
		return buff.wrecking_ball.up and buff.enrage.up
	end,
}

a.spells["whirlwind,if=!buff.meat_cleaver.up&spell_targets.whirlwind=2"] = {
	ID = 1680--[[Whirlwind]],
	NoRangeCheck = true,
	Melee = true,
	CheckFirst = function(z)
		return not buff.meat_cleaver.up and x.ActiveEnemies == 2
	end,
}

a.spells["raging_blow"] = {
	ID = 85288--[[Raging Blow]],
}

a.spells["furious_slash"] = {
	ID = 100130--[[Furious Slash]],
}

--[[
  _______ _                     _______                   _       
 |__   __| |                   |__   __|                 | |      
    | |  | |__  _ __ ___  ___     | | __ _ _ __ __ _  ___| |_ ___ 
    | |  | '_ \| '__/ _ \/ _ \    | |/ _` | '__/ _` |/ _ \ __/ __|
    | |  | | | | | |  __/  __/    | | (_| | | | (_| |  __/ |_\__ \
    |_|  |_| |_|_|  \___|\___|    |_|\__,_|_|  \__, |\___|\__|___/
                                                __/ |             
                                               |___/              ]]


a.spells["execute,if=buff.stone_heart.react"] = {
	ID = 5308--[[Execute]],
	CheckFirst = function(z)
		return x.Rage >= 25 and buff.stone_heart.up
	end,
	FlashColor = "Orange",
}

a.spells["rampage,if=buff.meat_cleaver.up&((buff.enrage.down&!talent.frothing_berserker.enabled)|(rage>=100&talent.frothing_berserker.enabled))|buff.massacre.react"] = {
	ID = 184367--[[Rampage]],
	CheckFirst = function(z)
		return x.CanRampage and (buff.meat_cleaver.up and ((buff.enrage.down and not talent.frothing_berserker.enabled) or (x.Rage >= 100 and talent.frothing_berserker.enabled)) or buff.massacre.up)
	end,
}

a.spells["raging_blow,if=talent.inner_rage.enabled"] = {
	ID = 85288--[[Raging Blow]],
	CheckFirst = function(z)
		return talent.inner_rage.enabled
	end,
}
