local AddonName, a = ...
if a.BuildFail(50000) then return end
local L = a.Localize
local s = SpellFlashAddon
local x = s.UpdatedVariables
local talent = x.Talent
local equipped = x.Equipped
local dot = x.Dot
local buff = x.Buff
local debuff = x.Debuff
local cooldown = x.Cooldown
local set_bonus = x.SetBonus

-- SpellFlash API:
-- http://wow.curseforge.com/addons/spellflash/pages/api/

-- Updated variable references:
-- http://wow.curseforge.com/addons/spellflash/pages/api/#w-local-x-spell-flash-addon-updated-variables
-- x.EnemyDetected, x.EnemyDetected, x.NoCC, x.InInstance, x.InstanceType, x.PetAlive, x.PetActiveEnemy, x.PetNoCC, x.Lag, x.DoubleLag, x.ThreatPercent, x.EnemyDetected, x.ShouldPermanentBuff, x.ShouldTemporaryBuff

-- Spell table references:
-- http://wow.curseforge.com/addons/spellflash/pages/api/#w-s-castable

a.spells["intercept"] = {
	ID = 198304--[[Intercept]],
	EnemyTargetNeeded = true,
	CheckFirst = function(z)
		return not s.MeleeDistance("target")
	end,
	NoGCD = true,
	FlashColor = "Purple",
}

a.spells["blood_fury"] = {
	ID = 20572--[[Blood Fury]],
	CheckFirst = function(z)
		return x.ShouldTemporaryBuff and s.Boss("target")
	end,
	NoGCD = true,
	FlashColor = "Yellow",
}

a.spells["berserking"] = {
	ID = 26297--[[Berserking]],
	CheckFirst = function(z)
		return x.ShouldTemporaryBuff and s.Boss("target")
	end,
	NoGCD = true,
	FlashColor = "Yellow",
}

a.spells["pummel"] = {
	ID = 6552--[[Pummel]],
	EnemyTargetNeeded = true,
	Interrupt = true,
	NoGCD = true,
	FlashColor = "Aqua",
}

a.spells["arcane_torrent"] = {
	ID = 69179--[[Arcane Torrent]],
	EnemyTargetNeeded = true,
	Interrupt = true,
	NoGCD = true,
	FlashColor = "Aqua",
}

a.spells["victory_rush"] = {
	ID = 34428--[[Victory Rush]],
	RequireBuff = 32216--[[Victorious]],
	RequireBuffUnit = "player",
	CheckFirst = function(z)
		return x.Health / x.MaxHealth <= 0.7
	end,
	FlashColor = "Red",
}

,"lights_judgment"

a.spells["potion,if=target.time_to_die<25"] = {
	Type = "item",
	ID = 229206--[[Potion of Prolonged Power]],
	EnemyTargetNeeded = true,
	NoGCD = true,
	Check = function(z)
		return x.ShouldTemporaryBuff and s.Boss("target") and x.TimeToDie < 25
	end,
	FlashColor = "Yellow",
	Continue = true,
	FlashID = {229206--[[Potion of Prolonged Power]], 127845--[[Unbending Potion]], 127844--[[Potion of the Old War]]},
}

a.spells["battle_cry,if=cooldown.shield_slam.remains=0"] = {
	ID = 1719--[[Battle Cry]],
	NoRangeCheck = true,
	CheckFirst = function(z)
		return x.ShouldTemporaryBuff and s.Boss("target") and cooldown.shield_slam.remains <= x.GCD
	end,
	NoGCD = true,
	Continue = true,
	FlashColor = "Yellow",
}

a.spells["demoralizing_shout"] = {
	ID = 1160--[[Demoralizing Shout]],
	NoRangeCheck = true,
	CheckFirst = function(z)
		return x.ShouldTemporaryBuff and s.Boss("target")
	end,
	NoGCD = true,
	Continue = true,
	FlashColor = "Yellow",
}

a.spells["shock_wave"] = {
	ID = 46968--[[Shock Wave]],
	NoRangeCheck = true,
	Melee = true,
	CheckFirst = function(z)
		return x.ActiveEnemies >= 3
	end,
}

a.spells["ravager,if=talent.ravager.enabled"] = {
	ID = 228920--[[Ravager]],
	CheckFirst = function(z)
		return talent.ravager.enabled
	end,
}

a.spells["shield_block,if=cooldown.shield_slam.remains=0"] = {
	ID = 2565--[[Shield Block]],
	Buff = 2565--[[Shield Block]],
	BuffUnit = "player",
	CheckFirst = function(z)
		x.ShieldBlock = x.Rage >= 15 and cooldown.shield_slam.remains <= x.GCD
		return x.ShieldBlock
	end,
	NoGCD = true,
	Continue = true,
	FlashColor = "Yellow",
}

a.spells["ignore_pain,if=(!talent.vengeance.enabled&buff.renewed_fury.remains<1.5)|(!talent.vengeance.enabled&rage.deficit>=40)|(buff.vengeance_ignore_pain.up)|(talent.vengeance.enabled&!buff.vengeance_ignore_pain.up&!buff.vengeance_revenge.up&rage<30&!buff.revenge.react)"] = {
	ID = 190456--[[Ignore Pain]],
	NoRangeCheck = true,
	CheckFirst = function(z)
		return not x.ShieldBlock and x.Rage >= s.If(buff.vengeance_ignore_pain.up, 13, 20) and ((not talent.vengeance.enabled and buff.renewed_fury.remains < 1.5) or (not talent.vengeance.enabled and x.RageDeficit >= 40) or (buff.vengeance_ignore_pain.up) or (talent.vengeance.enabled and not buff.vengeance_ignore_pain.up and not buff.vengeance_revenge.up and x.Rage < 30 and buff.revenge.down))
	end,
	NoGCD = true,
	Continue = true,
	FlashColor = "Yellow",
}

a.spells["shield_slam"] = {
	ID = 23922--[[Shield Slam]],
}

a.spells["revenge,if=(!talent.vengeance.enabled)|(talent.vengeance.enabled&buff.revenge.react&!buff.vengeance_ignore_pain.up)|(buff.vengeance_revenge.up)|(talent.vengeance.enabled&!buff.vengeance_ignore_pain.up&!buff.vengeance_revenge.up&rage>=30)"] = {
	ID = 6572--[[Revenge]],
	NoRangeCheck = true,
	CheckFirst = function(z)
		return (not talent.vengeance.enabled and x.Rage >= 30) or (talent.vengeance.enabled and buff.revenge.up and not buff.vengeance_ignore_pain.up) or (buff.vengeance_revenge.up and x.Rage >= 20) or (talent.vengeance.enabled and not buff.vengeance_ignore_pain.up and not buff.vengeance_revenge.up and x.Rage >= 30)
	end,
}

a.spells["thunder_clap"] = {
	ID = 6343--[[Thunder Clap]],
	NoRangeCheck = true,
	Melee = true,
	CheckFirst = function(z)
		return x.EnemyDetected
	end,
}

a.spells["devastate"] = {
	ID = 20243--[[Devastate]],
	CheckFirst = function(z)
		return not talent.devastator.enabled
	end,
}
